@@ -2,11 +2,13 @@
 jsonclass object should confirm to.
 """
 from __future__ import annotations
-from typing import TypeVar, ClassVar, Any, Union
+from typing import TypeVar, ClassVar, Any, Union, TYPE_CHECKING
 from bson.objectid import ObjectId
 from jsonclasses.jsonclass_object import JSONClassObject
-from .dbconf import DBConf
-from .query import ListQuery, IDQuery, SingleQuery
+if TYPE_CHECKING:
+    from .dbconf import DBConf
+    from .query import (ListQuery, IDQuery, SingleQuery, ExistQuery,
+                        IterateQuery)
 
 
 T = TypeVar('T', bound='PymongoObject')
@@ -35,9 +37,15 @@ class PymongoObject(JSONClassObject):
         ...
 
     @classmethod
-    def delete_by_id(cls: type[T], id: Union[str, ObjectId]) -> None:
+    def exist(cls: type[T], **kwargs: Any) -> ExistQuery[T]:
         ...
 
     @classmethod
-    def delete_many(cls: type[T], *args, **kwargs) -> int:
+    def iterate(cls: type[T], **kwargs: Any) -> IterateQuery[T]:
+        ...
+
+    def _orm_delete(self: T, no_raise: bool = False) -> None:
+        ...
+
+    def _orm_restore(self: T) -> None:
         ...
