@@ -1,14 +1,14 @@
 from __future__ import annotations
 from typing import Union, TYPE_CHECKING
 from inflection import camelize
-from jsonclasses.fields import FieldType
+from jsonclasses.field_definition import FieldType
 if TYPE_CHECKING:
-    from .base_mongo_object import BaseMongoObject
+    from .pymongo_object import PymongoObject
 
 
-def ref_key(key: str, cls: type[BaseMongoObject]) -> tuple[str, str]:
+def ref_key(key: str, cls: type[PymongoObject]) -> tuple[str, str]:
     field_name = key + '_id'
-    if cls.config.camelize_db_keys:
+    if cls.dbconf.camelize_db_keys:
         db_field_name = camelize(field_name, False)
     else:
         db_field_name = field_name
@@ -19,9 +19,9 @@ def ref_field_key(key: str) -> str:
     return key + '_id'
 
 
-def ref_db_field_key(key: str, cls: type[BaseMongoObject]) -> str:
+def ref_db_field_key(key: str, cls: type[PymongoObject]) -> str:
     field_name = ref_field_key(key)
-    if cls.config.camelize_db_keys:
+    if cls.dbconf.camelize_db_keys:
         db_field_name = camelize(field_name, False)
     else:
         db_field_name = field_name
@@ -32,9 +32,9 @@ def ref_field_keys(key: str) -> str:
     return key + '_ids'
 
 
-def ref_db_field_keys(key: str, cls: type[BaseMongoObject]) -> str:
+def ref_db_field_keys(key: str, cls: type[PymongoObject]) -> str:
     field_name = ref_field_keys(key)
-    if cls.config.camelize_db_keys:
+    if cls.dbconf.camelize_db_keys:
         db_field_name = camelize(field_name, False)
     else:
         db_field_name = field_name
